@@ -1,9 +1,7 @@
-import nltk
-
 from qai.issues.add_issues import parse
 
 
-def get_payload_stats(json_data):
+def get_payload_stats(json_data, nlp):
     try:
         _ = json_data.items()
         els = [json_data]
@@ -17,7 +15,7 @@ def get_payload_stats(json_data):
     try:
         for el in els:
             segment, _, _ = parse(el)
-            n_sent += len(nltk.sent_tokenize(segment))
+            n_sent += len(list(nlp(segment).sents))
             n_word += len(segment.split())
     except:
         # this will cause escaped exception in sanic logger
